bibliotheca Augustana

<<< Einführung
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge nôt ## Handschrift A ## um 1280 ## Hohenems-Münchener Handschrift ## nach der digitalen Edition ## von Hermann Reichert
___________________________________________________
###### 1 | keine Überschrift [C: Aventivre von den Nibelungen]
###### 2 | Aventivre von Sifride
###### 3 | Wie si ze Wormz chomen
###### 4 | Wie er mit den Sahsen stareit
###### 5 | Wie Sifrit Krimhilt erst gesach
###### 6 | Wie Gvnther gen Isenlande nach Prvnhilt fvor
###### 7 | Wie Gvnther Prvnhilde gewan
###### 8 | Wie Sifrit nach den Nibelvngen fvr
###### 9 | Wie Sifrit ze Wormz gesant wart
###### 10 | Wie Prvnhilt ze Wormz enphangen wart
###### 11 | Wie Sifrit ze lande mit sinem wibe kom
###### 12 | Wie Gvnther Sifriden zvo der hohzit bat
###### 13 | Wie si ze der hohzit fvrn
###### 14 | Wie die chvniginnen an ander schvlten
###### 15 | Wie Sifrit verraten wart
###### 16 | Wie Sifrit erslagen wart
###### 17 | Wie Sifrit bechlaget vñ begraben wart
###### 18 | Wie Sigmvnt wider ze lande fvr
###### 19 | Wie der Niblvnge hort ze Wormz chom
###### 20 | Wie chvnk Ezel ze Bvrgonden nach Krimhilt sande
###### 21 | Aventivr wie si hin fvr
###### 22 | Wie si zen Hvnen wart enphangen
###### 23 | Wie Krimhilt ir leit gedaht ze rechen
###### 24 | Wie Werbel vñ Svemel die botschaft wrben
###### 25 | Wie die herren alle zen Hevnen fvren
###### 26 | Wie Danchwart Gelffraten slvch
###### 27 | Von Rudigers
###### 28 | Wie Chrimhilt Hagen enphie
###### 29 | Wie gen if vf stvont
###### 30 | Wie si der schiltwaht phlagen
###### 31 | Wie si ze chirchen giengen
###### 32 | Wie Bloedelin erslagen wart
###### 33 | Wie die Bvrgonden mit den Hevnen striten
###### 34 | Wie si toten abe wurfen
###### 35 | Wie Irinch erslagen wart
###### 36 | Aventivr wie div chvnigin den sal beraiten hiez
###### 37 | Aventivr wie der marchgrave Rvodeger erslagen wart
###### 38 | Wie hern Dietriches man alle erslagen wrden
###### 39 | Av wie Gvnther vñ Chrimh' vñ Hagen wurden erslagen
Cgm 34, Bl. 1r: Strophen 1,1 - 25,3 Cgm 34, Bl. 11r: Strophen 250,3 - 275,1

<<< Einführung